#
# spec file for package python-jsonref
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jsonref
Version:        1.1.0
Release:        1.5
Summary:        An implementation of JSON Reference for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/gazpachoking/jsonref
Source:         https://files.pythonhosted.org/packages/source/j/jsonref/jsonref-%{version}.tar.gz
Patch1:         use-pdm-backend.patch
BuildRequires:  %{python_module pdm-backend}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
jsonref is a library for automatic dereferencing of JSON Reference
objects for Python (supporting 2.6+ including Python 3).

This library lets you use a data structure with JSON reference objects, as if
the references had been replaced with the referent data.

Features
* References are evaluated lazily. Nothing is dereferenced until it is used.
* Recursive references are supported, and create recursive python data
  structures.
References objects are actually replaced by lazy lookup proxy objects which are
almost completely transparent.
Complete docs can be found at http://jsonref.readthedocs.org/

%prep
%autosetup -p1 -n jsonref-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/jsonref.py
%{python_sitelib}/proxytypes.py
%pycache_only %{python_sitelib}/__pycache__/*
%{python_sitelib}/jsonref-%{version}.dist-info

%changelog
* Sat Jan 13 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Fixes documents where the root is a reference object not
    being cached
  * Allows a reference object to refer to a fragment within
    itself. fix #51, #40
  * Extra properties of a reference object will now have
    references resolved.
- update to 1.0.1:
  * Fix issue with proxies=False where it would not recurse
    through references to remove the proxies. #48
- update to 1.0.0:
  * `replace_refs` is now a function rather than a class method
    of `JsonRef` (The class method is still around, but
    deprecated.)
  * New options were also added to `replace_refs`
  * `jsonloader` is now a plan function rather than an instance
    of a class. (This is a breaking change if you were
    subclassing `JsonLoader`)
- add patch use-pdm-backend.patch: switch to more modern
  pdm-backend
* Thu Aug  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
- Remove devel dependency that is not needed
* Mon Feb  4 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 0.2 (python 3.7 support)
- Packaging : fix test call
* Tue May 22 2018 bruno@ioda-net.ch
- Packaging :
  + move do singlespec
  + spec-cleaner
  + Add tests
* Sat Oct 29 2016 termim@gmail.com
- initial checkin version 0.1
